Skip to contents

Get a specific field from a workflow

Usage

# S3 method for class 'workflow'
get_field(x, field, step_name, ...)

Arguments

x

A `workflow` object.

field

The name of the field to retrieve (e.g., "Name", "Comments").

step_name

Name of the step to retrieve the field from.

...

Additional arguments (not used).

Value

The value of the specified field from the workflow or a specific step.