new_workflowstate.Rd
This object keeps track of the state while executing a workflow, including the initial input, the last result, and the list of executed step runs.
new_workflowstate(initial_input = NULL, run_id = NULL)
The initial input provided to the workflow.
A unique identifier for the workflow run (optional).
A `workflowstate` object.