Null coalescing operator Returns left value if not NULL, otherwise right value.
null-coalescing-operator.RdNull coalescing operator Returns left value if not NULL, otherwise right value.
null-coalescing-operator.RdNull coalescing operator Returns left value if not NULL, otherwise right value.