Skip to contents

Generic method to remove a step from a workflow object.

Usage

remove_step(x, position, ...)

Arguments

x

The workflow object from which the step will be removed.

position

The position of the step to remove from the workflow.

...

Additional arguments passed to methods.

Value

The updated workflow object with the specified step removed.