Run the entire workflow
run.workflow.RdRun the entire workflow
Arguments
- x
A `workflow` object.
- state
A `workflowstate` object representing the initial state.
- from
An integer index of the step to start from.
- to
An integer index of the step to end at.
- env
An environment to look up command functions. Defaults to `NULL`, which uses each step's own env or the caller's env.
- ...
Additional arguments passed to `run.workflowstep()`.