Generic method to add a step to a workflow object.
Usage
add_step(x, new_step, position, ...)
Arguments
- x
The workflow object to which the step will be added.
- new_step
The step to add to the workflow.
- position
The position in the workflow where the new step should be added.
- ...
Additional arguments passed to methods.
Value
The updated workflow object with the new step added.