Convert a workflow object to commands.json record format
as.commands_record.workflow.RdThis method converts a `workflow` object into a list format suitable for writing to a `commands.json` file, which is used to define the workflow steps in a structured way. It applies the conversion to each step in the workflow.
Usage
# S3 method for class 'workflow'
as.commands_record(x, ...)