Convert a workflowstep to commands.json record format
as.commands_record.workflowstep.RdThis method converts a `workflowstep` object into a list format suitable for writing to a `commands.json` file, which is used to define the workflow steps in a structured way.
Usage
# S3 method for class 'workflowstep'
as.commands_record(x, ...)