Skip to contents

This function summarizes the workflow state by converting the list of step runs into a data frame.

Usage

# S3 method for class 'workflowstate'
as.data.frame(x, ...)

Arguments

x

A `workflowstate` object.

...

Additional arguments (not used).

Value

A data frame summarizing the workflow state.