Convert a workflowstate to a data frame
as.data.frame.workflowstate.RdThis function summarizes the workflow state by converting the list of step runs into a data frame.
Usage
# S3 method for class 'workflowstate'
as.data.frame(x, ...)as.data.frame.workflowstate.RdThis function summarizes the workflow state by converting the list of step runs into a data frame.
# S3 method for class 'workflowstate'
as.data.frame(x, ...)