Skip to contents

This object represents a completed run of a workflow, containing the workflow definition and the final state after execution.

Usage

new_workflowrun(workflow, state)

Arguments

workflow

A `workflow` object.

state

A `workflowstate` object.

Value

A `workflowrun` object.