Workflow run object
new_workflowrun.RdThis object represents a completed run of a workflow, containing the workflow definition and the final state after execution.
new_workflowrun.RdThis object represents a completed run of a workflow, containing the workflow definition and the final state after execution.