Create a new workflow state object
new_workflowstate.RdThis object keeps track of the state while executing a workflow, including the initial input, the last result, and the list of executed step runs.
new_workflowstate.RdThis object keeps track of the state while executing a workflow, including the initial input, the last result, and the list of executed step runs.