Remove a step from the workflow
remove_step.workflow.RdThis method removes a `workflowstep` from the `steps` list of a `workflow` object at a specified position. It also performs validation after removing the step and updates the current index and entries of all steps to maintain consistency.
Usage
# S3 method for class 'workflow'
remove_step(x, position, ...)