run.Rd
Run a workflow step This is a generic function to run a workflow step or an entire workflow.
run(object, state, ...)
A `workflowstep` object or a `workflow` object.
A `workflowstate` object.
Additional arguments (not used).
A `workflowsteprun` object representing the result of executing the step or a list containing the updated `workflow` and `workflowstate` objects.