Run a workflow step
run.workflowstep.RdThis function executes a single workflow step, updating the workflow state with the result or error from the step execution.
Usage
# S3 method for class 'workflowstep'
run(object, state, env = NULL, ...)run.workflowstep.RdThis function executes a single workflow step, updating the workflow state with the result or error from the step execution.
# S3 method for class 'workflowstep'
run(object, state, env = NULL, ...)