Update a workflow step with a new value
update.workflow.RdThis function updates a specific field of a `workflowstep` object with a new value. It is used to modify step details such as name, label, comments, command, parameters, or loop settings.
Usage
# S3 method for class 'workflow'
update(x, step, field, value, ...)