Update the input list of a workflow
update_input_list.workflow.RdThis method updates the `input_list` of a `workflow` object and optionally writes the updated list to the corresponding inputs file if the workflow is file-backed.
Usage
# S3 method for class 'workflow'
update_input_list(x, new_list, write_file = TRUE, ...)